@@ -1,6 +1,7 @@
 """
 A storage area for templates as strings
 """
+from __future__ import unicode_literals
 
 # utils.sh is the same for every namespace, only sourced once
 shell_utils_template = """
@@ -39,3 +40,11 @@ __          __     _____  _   _ _____ _   _  _____
    \  /\  / ____ \| | \ \| |\  |_| |_| |\  | |__| |
     \/  \/_/    \_\_|  \_\_| \_|_____|_| \_|\_____|
 """
+
+sprinter_template = """
+   _____  ____   ____   ____ _   __ ______ ______ ____
+  / ___/ / __ \ / __ \ /  _// | / //_  __// ____// __ \\
+  \__ \ / /_/ // /_/ / / / /  |/ /  / /  / __/  / /_/ /
+ ___/ // ____// _, _/_/ / / /|  /  / /  / /___ / _, _/
+/____//_/    /_/ |_|/___//_/ |_/  /_/  /_____//_/ |_|
+"""
