@@ -10,8 +10,10 @@ from collections import defaultdict
 
 import sprinter.lib as lib
 from sprinter.core import PHASE, load_global_config, Directory, Injections, Manifest, load_manifest, FeatureDict
-from sprinter.core.templates import shell_utils_template, source_template
-from sprinter.lib import SprinterException, system
+from sprinter.core.templates import shell_utils_template, source_template, warning_template
+from sprinter.core.messages import REMOVE_WARNING
+from sprinter.lib import system
+from sprinter.exceptions import SprinterException, FormulaException
 from sprinter.external import brew
 
 
@@ -70,6 +72,8 @@ class Environment(object):
     source = None  # the path to the source handle, the handle itself, or a manifest instance
     target = None  # the path to the target handle, the handle itself, or a manifest instance
     namespace = None  # the namespace of the environment
+    custom_directory_root = None  # the root to install directories too
+    do_inject_environment_config = True  # inject configuration into shells
     sprinter_namespace = None  # the namespace to make installs with. this affects:
     phase = None  # the phase currently running
     # the prefix added to injections
@@ -112,20 +116,20 @@ class Environment(object):
         self.global_path = os.path.join(self.root, ".global")
         self.global_config_path = os.path.join(self.global_path, "config.cfg")
         self.global_config = global_config or load_global_config(self.global_config_path)
-        
+
         self.shell_util_path = os.path.join(self.global_path, "utils.sh")
         self.main_manifest = None
 
         # a dictionary of the errors associated with features.
         # The key is a tuple of feature name and formula, while the value is an instance.
         self._error_dict = defaultdict(list)
-        
+
     @warmup
     def install(self):
         """ Install the environment """
         self.phase = PHASE.INSTALL
         if not self.directory.new:
-            self.logger.info("Namespace %s already exists!" % self.namespace)
+            self.logger.info("Namespace %s directory already exists!" % self.namespace)
             self.source = load_manifest(self.directory.manifest_path)
             return self.update()
         try:
@@ -133,6 +137,7 @@ class Environment(object):
             self.directory.initialize()
             self.install_sandboxes()
             self.instantiate_features()
+            self.grab_inputs()
             self._specialize()
             for feature in self.features.run_order:
                 self.run_action(feature, 'sync')
@@ -147,7 +152,7 @@ class Environment(object):
                 self.directory.remove()
                 et, ei, tb = sys.exc_info()
                 reraise(et, ei, tb)
-        
+
     @warmup
     @install_required
     def update(self, reconfigure=False):
@@ -160,6 +165,10 @@ class Environment(object):
             # We don't grab inputs, only on install
             # updates inputs are grabbed on demand
             # self.grab_inputs(reconfigure=reconfigure)
+            if reconfigure:
+                self.grab_inputs(reconfigure=True)
+            else:
+                self._copy_source_to_target()
             self._specialize(reconfigure=reconfigure)
             for feature in self.features.run_order:
                 self.run_action(feature, 'sync')
@@ -180,10 +189,17 @@ class Environment(object):
             self.instantiate_features()
             self._specialize()
             for feature in self.features.run_order:
-                self.run_action(feature, 'sync')
+                try:
+                    self.run_action(feature, 'sync')
+                except FormulaException:
+                    # continue trying to removal any remaining features.
+                    pass
             self.clear_all()
             self.directory.remove()
             self.injections.commit()
+            if self.error_occured:
+                self.logger.error(warning_template)
+                self.logger.error(REMOVE_WARNING)
         except Exception:
             self.logger.debug("", exc_info=sys.exc_info())
             et, ei, tb = sys.exc_info()
@@ -247,10 +263,13 @@ class Environment(object):
 
     @warmup
     def inject_environment_config(self):
+        if not self.do_inject_environment_config:
+            return
+
         for shell in SHELL_CONFIG:
             if shell == 'gui':
                 if system.is_debian():
-                    self._inject_config_source(".env", SHELL_CONFIG['gui']['debian'])
+                    self._inject_config_source(".gui", SHELL_CONFIG['gui']['debian'])
             else:
                 if (self.global_config.has_option('shell', shell)
                    and lib.is_affirmative(self.global_config.get('shell', shell))):
@@ -316,15 +335,18 @@ class Environment(object):
     def write_debug_log(self, file_path):
         """ Write the debug log to a file """
         with open(file_path, "w+") as fh:
-            fh.write(self._debug_stream.getvalue())
-            fh.write("The following errors occured:\n")
+            fh.write(system.get_system_info().encode('utf-8'))
+            # writing to debug stream
+            self._debug_stream.seek(0)
+            fh.write(self._debug_stream.read().encode('utf-8'))
+            fh.write("The following errors occured:\n".encode('utf-8'))
             for error in self._errors:
-                fh.write(error + "\n")
+                fh.write((error + "\n").encode('utf-8'))
             for k, v in self._error_dict.items():
                 if len(v) > 0:
-                    fh.write("Error(s) in %s with formula %s:\n" % k)
+                    fh.write(("Error(s) in %s with formula %s:\n" % k).encode('utf-8'))
                     for error in v:
-                        fh.write(error + "\n")
+                        fh.write((error + "\n").encode('utf-8'))
 
     def write_manifest(self):
         """ Write the manifest to the file """
@@ -364,10 +386,15 @@ class Environment(object):
             else:
                 raise SprinterException("No environment name has been specified!")
 
+        self.directory_root = self.custom_directory_root
+
         if not self.directory:
-            self.directory = Directory(self.namespace,
-                                       sprinter_root=self.root,
+            if not self.directory_root:
+                self.directory_root = os.path.join(self.root, self.namespace)
+
+            self.directory = Directory(self.directory_root,
                                        shell_util_path=self.shell_util_path)
+
         if not self.injections:
             self.injections = Injections(wrapper="%s_%s" % (self.sprinter_namespace.upper(),
                                                             self.namespace),
@@ -387,8 +414,7 @@ class Environment(object):
         """
         # src_path = os.path.join(self.directory.root_dir, source_filename)
         # src_exec = "[ -r %s ] && . %s" % (src_path, src_path)
-        src_exec = "[ -r %s/%s ] && . %s/%s" % (self.directory.root_dir, source_filename,
-                                                self.directory.root_dir, source_filename)
+        src_exec = "[ -r {0} ] && . {0}".format(os.path.join(self.directory.root_dir, source_filename))
         # The ridiculous construction above is necessary to avoid failing tests(!)
 
         for config_file in files_to_inject:
@@ -426,9 +452,6 @@ class Environment(object):
             self.logger.debug("Global directory doesn't exist! creating...")
             os.makedirs(os.path.join(self.root, ".global"))
 
-        self.logger.debug("Writing global config...")
-        self.global_config.write(open(self.global_config_path, 'w+'))
-
         self.logger.debug("Writing shell util file...")
         with open(self.shell_util_path, 'w+') as fh:
             fh.write(shell_utils_template)
@@ -468,16 +491,19 @@ class Environment(object):
         self._errors += [error_message]
         self.logger.error(error_message)
 
+    def log_feature_error(self, feature, error_message):
+        if type(error_message) != list:
+            error_message = "Error occured! %s" % str(error_message)
+            self._error_dict[feature] += [error_message]
+        else:
+            self._error_dict[feature] += error_message
+        self.log_error(error_message)
+
     def get_error_value(self, feature):
         """ get the error value for a feature """
         if feature not in self._error_dict:
-            self._error_dict1
+            self._error_dict1               #
 
-    def log_feature_error(self, feature, error_message):
-        self.error_occured = True
-        self._error_dict[feature] += [error_message]
-        self.logger.error(error_message)
-            
     def run_action(self, feature, action, run_if_error=False):
         """ Run an action, and log it's output in case of errors """
         if len(self._error_dict[feature]) > 0 and not run_if_error:
@@ -486,13 +512,7 @@ class Environment(object):
         try:
             result = getattr(instance, action)()
             if result:
-                if type(result) != list:
-                    self.log_feature_error(feature,
-                                           "Error occurred! %s" % str(result))
-                else:
-                    self._error_dict[feature] += result
-            if len(self._error_dict[feature]) > 0:
-                self.error_occured = True
+                self.log_feature_error(feature, result)
         # catch a generic exception within a feature
         except Exception:
             e = sys.exc_info()[1]
@@ -500,6 +520,15 @@ class Environment(object):
                              (action, feature))
             self.logger.debug("Exception", exc_info=sys.exc_info())
             self.log_feature_error(feature, str(e))
+        # any error in a feature should fail immediately - unless it occurred
+        # from the remove() method in which case continue the rest of the
+        # feature removal from there
+        if self.error_occured:
+            exception_msg = "%s action failed for feature %s!" % (action, feature)
+            if self.phase == PHASE.REMOVE:
+                raise FormulaException(exception_msg)
+            else:
+                raise SprinterException(exception_msg)
 
     def _specialize(self, reconfigure=False):
         """ Add variables and specialize contexts """
@@ -512,19 +541,21 @@ class Environment(object):
                     context_dict['config:root_dir'] = self.directory.root_dir
                     context_dict['config:node'] = system.NODE
                 manifest.add_additional_context(context_dict)
-        self.grab_inputs()
         for feature in self.features.run_order:
             self.run_action(feature, 'validate', run_if_error=True)
             if not reconfigure:
                 self.run_action(feature, 'resolve')
             self.run_action(feature, 'prompt')
 
+    def _copy_source_to_target(self):
+        """ copy source user configuration to target """
+        if self.source and self.target:
+            for k, v in self.source.items('config'):
+                # always have source override target.
+                self.target.set_input(k, v)
+
     def grab_inputs(self, reconfigure=False):
         """ Resolve the source and target config section """
-        if self.source:
-            if self.target:
-                for k, v in self.source.items('config'):
-                    if not self.target.has_option('config', k):
-                        self.target.set('config', k, v)
+        self._copy_source_to_target()
         if self.target:
             self.target.grab_inputs(force=reconfigure)
