@@ -6,13 +6,15 @@ formula = sprinter.formula.package
 apt-get = git
 brew = git
 """
+from __future__ import unicode_literals
 import logging
 from sprinter import lib
 from sprinter.lib import system
 from sprinter.formula.base import FormulaBase
+from sprinter.exceptions import FormulaException
 
 
-class PackageFormulaException(Exception):
+class PackageFormulaException(FormulaException):
     """ Errors with the package formula """
 
 
