@@ -16,11 +16,14 @@ write_password_p4settings = true
 overwrite_p4settings = false
 overwrite_client = false
 """
+from __future__ import unicode_literals
 import os
 import re
 import shutil
 import sprinter.lib as lib
+from sprinter.lib import system
 from sprinter.core import PHASE
+from sprinter.exceptions import FormulaException
 from sprinter.formula.base import FormulaBase
 
 P4V_APPLICATIONS = ['p4v.app', 'p4admin.app', 'p4merge.app']
@@ -43,9 +46,14 @@ package_dict = {
             "p4v": "r13.2/bin.linux26x86_64/p4v.tgz"}
     }
 }
-                
-    
-class PerforceFormulaException(Exception):
+
+WRITE_P4PASSWD_MESSAGE = """
+Insert the perforce password to your p4settings?
+(password will be stored in plaintext in a file in your perforce root)
+""".strip()
+
+
+class PerforceFormulaException(FormulaException):
     """Exceptions for perforce formula"""
 
 
@@ -58,48 +66,41 @@ class PerforceFormula(FormulaBase):
                                                  'client_default',
                                                  'client']
 
-    required_options = FormulaBase.required_options + ['version', 'root_path', 'username',
-                                                       'password', 'port', 'p4view']
+    required_options = FormulaBase.required_options + ['version', 'root_path',
+                                                       'username', 'password',
+                                                       'port', 'p4view']
 
     def prompt(self):
-        if self.target:
-            if not self.target.has('write_p4settings'):
-                self.target.prompt('write_p4settings', 'Write a p4settings file?', default='yes')
-                self.target.set_if_empty('write_p4settings', True)
+        if self.environment.phase in (PHASE.INSTALL, PHASE.UPDATE):
+            self._prompt_value('write_p4settings', "Write a p4settings file?", default="yes")
 
-            if self.environment.phase in (PHASE.INSTALL, PHASE.UPDATE):
-                if self.target.is_affirmative('write_p4settings'):
-                    p4settings_path = os.path.join(os.path.expanduser(self.target.get('root_path')),
-                                                   '.p4settings')
+            if self.target.is_affirmative('write_p4settings'):
+                p4settings_path = os.path.join(os.path.expanduser(self.target.get('root_path')),
+                                               '.p4settings')
+                write_p4settings = True
 
-                    if os.path.exists(p4settings_path):
-                        self.target.prompt(
-                            "overwrite_p4settings",
-                            "p4settings already exists at %s. Overwrite?" % self.target.get('root_path'),
-                            default="no", only_if_empty=True)
+                if os.path.exists(p4settings_path):
+                    self._prompt_value("overwrite_p4settings",
+                                       "p4settings already exists at {0}. Overwrite?".format(self.target.get('root_path')),
+                                       default="no")
+                    write_p4settings = self.target.is_affirmative('overwrite_p4settings')
 
-                    if (self.target.is_affirmative('write_p4settings') and
-                        (not os.path.exists(p4settings_path)
-                         or self.target.is_affirmative('overwrite_p4settings', default=False))):
-                        self.target.prompt(
-                            "write_password_p4settings",
-                            "Insert the perforce password to your p4settings?\n" +
-                            "(password will be stored in plaintext in a file in your perforce root)\n",
-                            default="no", only_if_empty=True)
-                self.target.prompt(
-                    "client",
-                    "Please choose your perforce client",
-                    default=self.target.get('client_default', ''), only_if_empty=True)
-            self.target.prompt(
-                "overwrite_client",
-                "Would you like to overwrite the client workspace in perforce?",
-                default="yes", only_if_empty=True)
+                if write_p4settings:
+                    self._prompt_value("write_password_p4settings",
+                                       WRITE_P4PASSWD_MESSAGE,
+                                       default="no")
+
+            self._prompt_value("client", "Please choose your perforce client",
+                               default=self.target.get('client_default', ''))
+
+            self._prompt_value("overwrite_client",
+                               "Would you like to overwrite the client workspace in perforce?",
+                               default="yes")
 
         elif self.environment.phase == PHASE.REMOVE:
-                self.source.prompt(
-                    "remove_p4root",
-                    "Would you like to completely remove the p4 directory?",
-                    default="no", only_if_empty=True)
+                self._prompt_value("remove_p4root",
+                                   "Would you like to completely remove the p4 directory?",
+                                   default="no")
 
     def install(self):
         config = self.target
@@ -136,14 +137,14 @@ class PerforceFormula(FormulaBase):
         if version not in package_dict:
             raise PerforceFormulaException("Version %s in not supported by perforce formula!\n" % version +
                                            "Supported versions are: %s" % ", ".join(package_dict.keys()))
-        
+
     def __install_perforce(self, config):
         """ install perforce binary """
-        if not self.system.is64bit():
+        if not system.is_64_bit():
             self.logger.warn("Perforce formula is only designed for 64 bit systems! Not install executables...")
             return False
         version = config.get('version', 'r13.2')
-        key = 'osx' if self.system.isOSX() else 'linux'
+        key = 'osx' if system.is_osx() else 'linux'
         perforce_packages = package_dict[version][key]
         d = self.directory.install_directory(self.feature_name)
         if not os.path.exists(d):
@@ -154,12 +155,12 @@ class PerforceFormula(FormulaBase):
         self.directory.symlink_to_bin("p4", os.path.join(d, "p4"))
         self.p4_command = os.path.join(d, "p4")
         self.logger.info("Installing p4v...")
-        if self.system.isOSX():
-            return self.__install_p4v_osx(url_prefix + perforce_packages['p4v'])
+        if system.is_osx():
+            return self._install_p4v_osx(url_prefix + perforce_packages['p4v'])
         else:
-            return self.__install_p4v_linux(url_prefix + perforce_packages['p4v'])
+            return self._install_p4v_linux(url_prefix + perforce_packages['p4v'])
 
-    def __install_p4v_osx(self, url, overwrite=False):
+    def _install_p4v_osx(self, url, overwrite=False):
         """ Install perforce applications and binaries for mac """
         package_exists = False
         root_dir = os.path.expanduser(os.path.join("~", "Applications"))
@@ -170,14 +171,15 @@ class PerforceFormula(FormulaBase):
             self.logger.warn("P4V exists already in %s! Not overwriting..." % root_dir)
         return True
 
-    def __install_p4v_linux(self, url):
+    def _install_p4v_linux(self, url):
         """ Install perforce applications and binaries for linux """
         lib.extract_targz(url,
                           self.directory.install_directory(self.feature_name),
                           remove_common_prefix=True)
         bin_path = os.path.join(self.directory.install_directory(self.feature_name), 'bin')
-        for f in os.listdir(bin_path):
-            self.directory.symlink_to_bin(f, os.path.join(bin_path, f))
+        if os.path.exists(bin_path):
+            for f in os.listdir(bin_path):
+                self.directory.symlink_to_bin(f, os.path.join(bin_path, f))
         return True
 
     def __write_p4settings(self, config):
@@ -207,7 +209,7 @@ class PerforceFormula(FormulaBase):
         client_dict = config.to_dict()
         client_dict['root_path'] = os.path.expanduser(config.get('root_path'))
         os.chdir(client_dict['root_path'])
-        client_dict['hostname'] = self.system.node
+        client_dict['hostname'] = system.NODE
         client_dict['p4view'] = config['p4view'] % self.environment.target.get_context_dict()
         client = re.sub('//depot', '    //depot', p4client_template % client_dict)
         self.logger.info(lib.call("%s client -i" % self.p4_command,
