@@ -11,6 +11,7 @@ user = toumorokoshi
 create = false
 install_command = echo 'hello'
 """
+from __future__ import unicode_literals
 import os
 import logging
 
@@ -31,24 +32,19 @@ ssh_config_path = os.path.join(user_ssh_path, "config")
 
 class SSHFormula(FormulaBase):
 
-    required_options = FormulaBase.required_options + ['keyname', 'hostname', 'user', 'host']
-    valid_options = FormulaBase.valid_options + ['override', 'install_command', 'create',
-                                                 'nopassphrase', 'type', 'ssh_path', 'use_global_ssh']
+    required_options = FormulaBase.required_options + ['keyname', 'hostname',
+                                                       'user', 'host']
+    valid_options = FormulaBase.valid_options + ['override', 'install_command',
+                                                 'create', 'nopassphrase',
+                                                 'type', 'ssh_path',
+                                                 'use_global_ssh', 'port']
 
     def prompt(self):
         if self.environment.phase in (PHASE.INSTALL, PHASE.UPDATE):
             if os.path.exists(ssh_config_path):
-                if not self.target.has('use_global_ssh') and self.__global_ssh_key_exists():
-                    self.target.prompt("use_global_ssh",
-                                       "A standard global ssh key was detected! Would you like to use the global ssh key?",
-                                       default="no")
-                if (self.injections.in_noninjected_file(
-                        ssh_config_path, "Host %s" % self.target.get('host')) and
-                   not self.target.has('override')):
-                    self.logger.info("SSH config for host %s already exists! Override?" %
-                                     self.target.get('host'))
-                    self.logger.info("Your existing config will not be overwritten, simply inactive.")
-                    self.target.set('override', lib.prompt("Override?", boolean=True, default="no"))
+                self._prompt_value('use_global_ssh',
+                                   "Would you like to manage your own ssh configuration?",
+                                   default="no")
 
     def install(self):
         self.__generate_key(self.target)
@@ -73,12 +69,12 @@ class SSHFormula(FormulaBase):
         """
         Generate the ssh key, and return the ssh config location
         """
-        command = "ssh-keygen -t %(type)s -f %(keyname)s -N  " % config.to_dict()
         cwd = config.get('ssh_path', self.directory.install_directory(self.feature_name))
         if not config.has('create') or config.is_affirmative('create'):
             if not os.path.exists(cwd):
                 os.makedirs(cwd)
             if not os.path.exists(os.path.join(cwd, config.get('keyname'))):
+                command = "ssh-keygen -t %(type)s -f %(keyname)s -N  " % config.to_dict()
                 lib.call(command, cwd=cwd, output_log_level=logging.DEBUG)
         if not config.has('ssh_path'):
             config.set('ssh_path', cwd)
@@ -88,16 +84,20 @@ class SSHFormula(FormulaBase):
         """
         Install the ssh configuration
         """
-        if not self.__global_ssh_key_exists() or not config.is_affirmative('use_global_ssh', default="no"):
-            ssh_config_injection = ssh_config_template % config.to_dict()
-            if os.path.exists(ssh_config_path):
+        if not config.is_affirmative('use_global_ssh', default="no"):
+            ssh_config_injection = self._build_ssh_config(config)
+
+            if not os.path.exists(ssh_config_path):
+
                 if self.injections.in_noninjected_file(ssh_config_path, "Host %s" % config.get('host')):
                     if config.is_affirmative('override'):
                         self.injections.inject(ssh_config_path, ssh_config_injection)
                 else:
                     self.injections.inject(ssh_config_path, ssh_config_injection)
+
             else:
                 self.injections.inject(ssh_config_path, ssh_config_injection)
+
             self.injections.commit()
 
     def __call_command(self, command, ssh_path):
@@ -106,8 +106,14 @@ class SSHFormula(FormulaBase):
         command = command.replace('{{ssh}}', ssh_contents)
         lib.call(command, shell=True, output_log_level=logging.DEBUG)
 
-    def __global_ssh_key_exists(self):
-        """ Check if the global ssh keys exists """
-        return (os.path.exists(os.path.join(user_ssh_path, "id_dsa")) or 
-                os.path.exists(os.path.join(user_ssh_path, "id_ecdsa")) or 
-                os.path.exists(os.path.join(user_ssh_path, "id_rsa")))
+    def _build_ssh_config(self, config):
+        """ build the ssh injection configuration """
+        ssh_config_injection = ssh_config_template % {
+            'host': config.get('host'),
+            'hostname': config.get('hostname'),
+            'ssh_key_path': config.get('ssh_key_path'),
+            'user': config.get('user')
+        }
+        if config.has('port'):
+            ssh_config_injection += "  Port {0}\n".format(config.get('port'))
+        return ssh_config_injection
