@@ -1,11 +1,13 @@
 """Sprinter, an environment installation and management tool.
 Usage:
-  sprinter install <environment_source> [-avi -n <namespace> -u <username> -p <password> --allow-bad-certificate]
+  sprinter install <environment_source> [-avi -n <namespace> -u <username> -p <password> -l <local_path> --allow-bad-certificate]
   sprinter update <environment_name> [-ravi -u <username> -p <password> --allow-bad-certificate]
   sprinter (remove | deactivate | activate) <environment_name> [-v]
   sprinter validate <environment_source> [-avi -u <username> -p <password> --allow-bad-certificate]
   sprinter environments
+  sprinter globals [-r]
   sprinter (-h | --help)
+  sprinter (-V | --version)
 
 Options:
   -h, --help                                Show this usage guide.
@@ -15,21 +17,25 @@ Options:
   -a, --auth                                When pulling environment configurations, attempt basic authentication
   -u <username>, --username <username>      When using basic authentication, this is the username used
   -p <password>, --password <password>      When using basic authentication, this is the password used
-  --allow-bad-certificate                   Do not verify ssl certificates when pulling environment configurations
+  -l, --local <local_path>                  Intall the environment as a local. This installs objects relative to the local directory, and doesn't inject.
   -i, --ignore-errors                       Ignore errors in a formula
+  --allow-bad-certificate                   Do not verify ssl certificates when pulling environment configurations
+  -V, --version                             Show version.
 """
-
+from __future__ import unicode_literals
 import logging
 import os
 import signal
 import sys
+import pkg_resources
 from docopt import docopt
 
 import sprinter.lib as lib
-from sprinter.core import PHASE, Manifest, ManifestException, load_manifest, Directory
+from sprinter.core import PHASE, Manifest, ManifestException, Directory, manifest
 from sprinter.environment import Environment
-from sprinter.lib import SprinterException, BadCredentialsException
-
+from sprinter.exceptions import SprinterException
+from sprinter.lib.request import BadCredentialsException
+from sprinter.core.globals import print_global_config, configure_config, write_config
 
 def signal_handler(signal, frame):
     print("\nShutting down sprinter...")
@@ -56,7 +62,7 @@ def error(message):
 
 
 def parse_args(argv, Environment=Environment):
-    options = docopt(__doc__, argv=argv, version="Sprinter 1.0")
+    options = docopt(__doc__, argv=argv, version= pkg_resources.get_distribution('sprinter').version)
     logging_level = logging.DEBUG if options['--verbose'] else logging.INFO
     # start processing commands
     env = Environment(logging_level=logging_level, ignore_errors=options['--ignore-errors'])
@@ -73,49 +79,71 @@ def parse_args(argv, Environment=Environment):
             signal.signal(signal.SIGINT, handle_install_shutdown)
             if options['--username'] or options['--auth']:
                 options = get_credentials(options, parse_domain(target))
-                target = load_manifest(target,
-                                       username=options['<username>'],
-                                       password=options['<password>'],
-                                       verify_certificate=(not options['--allow-bad-certificate']))
+                target = manifest.load_manifest(
+                    target,
+                    username=options['<username>'],
+                    password=options['<password>'],
+                    verify_certificate=(not options['--allow-bad-certificate'])
+                )
+            else:
+                target = manifest.load_manifest(
+                    target,
+                    verify_certificate=(not options['--allow-bad-certificate'])
+                )
             env.target = target
             if options['--namespace']:
                 env.namespace = options['<namespace>']
+            if options['--local']:
+                env.do_inject_environment_config = False
+                env.custom_directory_root = os.path.abspath(os.path.expanduser(options['--local']))
             env.install()
 
         elif options['update']:
             target = options['<environment_name>']
-            env.directory = Directory(target,
-                                      sprinter_root=env.root,
+            env.directory = Directory(os.path.join(env.root, target),
                                       shell_util_path=env.shell_util_path)
-            env.source = load_manifest(env.directory.manifest_path)
+            env.source = manifest.load_manifest(
+                env.directory.manifest_path, do_inherit=False
+            )
             use_auth = options['--username'] or options['--auth']
             if use_auth:
                 options = get_credentials(options, target)
-            env.target = load_manifest(env.source.source(),
-                                       username=options['<username>'] if use_auth else None,
-                                       password=options['<password>'] if use_auth else None,
-                                       verify_certificate=(not options['--allow-bad-certificate']))
+            env.target = manifest.load_manifest(
+                env.source.source(),
+                username=options['<username>'] if use_auth else None,
+                password=options['<password>'] if use_auth else None,
+                verify_certificate=(not options['--allow-bad-certificate'])
+            )
             env.update(reconfigure=options['--reconfigure'])
 
         elif options["remove"]:
-            env.directory = Directory(options['<environment_name>'],
-                                      sprinter_root=env.root,
+            env.directory = Directory(os.path.join(env.root, options['<environment_name>']),
                                       shell_util_path=env.shell_util_path)
-            env.source = load_manifest(env.directory.manifest_path, namespace=options['<environment_name>'])
+            env.source = manifest.load_manifest(
+                env.directory.manifest_path,
+                namespace=options['<environment_name>'],
+                do_inherit=False
+            )
             env.remove()
 
         elif options['deactivate']:
-            env.directory = Directory(options['<environment_name>'],
-                                      sprinter_root=env.root,
+            env.directory = Directory(os.path.join(env.root, options['<environment_name>']),
                                       shell_util_path=env.shell_util_path)
-            env.source = load_manifest(env.directory.manifest_path, namespace=options['<environment_name>'])
+            env.source = manifest.load_manifest(
+                env.directory.manifest_path,
+                namespace=options['<environment_name>'],
+                do_inherit=False
+            )
             env.deactivate()
 
         elif options['activate']:
-            env.directory = Directory(options['<environment_name>'],
-                                      sprinter_root=env.root,
+            env.directory = Directory(os.path.join(env.root, options['<environment_name>']),
                                       shell_util_path=env.shell_util_path)
-            env.source = load_manifest(env.directory.manifest_path, namespace=options['<environment_name>'])
+            env.source = manifest.load_manifest(
+                env.directory.manifest_path,
+                namespace=options['<environment_name>'],
+                do_inherit=False
+            )
             env.activate()
 
         elif options['environments']:
@@ -127,16 +155,24 @@ def parse_args(argv, Environment=Environment):
         elif options['validate']:
             if options['--username'] or options['--auth']:
                 options = get_credentials(options, parse_domain(target))
-                target = load_manifest(options['<environment_source>'],
-                                       username=options['<username>'],
-                                       password=options['<password>'],
-                                       verify_certificate=(not options['--allow-bad-certificate']))
+                target = manifest.load_manifest(
+                    options['<environment_source>'],
+                    username=options['<username>'],
+                    password=options['<password>'],
+                    verify_certificate=(not options['--allow-bad-certificate'])
+                )
             env.target = options['<environment_source>']
             env.validate()
             if not env.error_occured:
                 print("No errors! Manifest is valid!")
             else:
                 "Manifest is invalid! Please see errors above."
+        elif options['globals']:
+            if options['--reconfigure']:
+                configure_config(env.global_config, reconfigure=True)
+                write_config(env.global_config, env.global_config_path)
+            else:
+                print_global_config(env.global_config)
     except BadCredentialsException:
         e = sys.exc_info()[1]
         raise e
